/*
 * Copyright 2009 SpringSource
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.bundlor.support.contributors;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.util.Set;

import org.junit.Test;

import com.springsource.bundlor.support.partialmanifest.ReadablePartialManifest;
import com.springsource.bundlor.support.partialmanifest.StandardReadablePartialManifest;

public class Log4JXmlArtifactAnalyzerTests {

    private final Log4JXmlArtifactAnalyzer analyzer = new Log4JXmlArtifactAnalyzer();

    @Test
    public void canAnalyze() {
        assertTrue(analyzer.canAnalyse("log4j.xml"));
        assertFalse(analyzer.canAnalyse("META-INF/log4j.xml"));
    }

    @Test
    public void example1() throws FileNotFoundException, Exception {
        ReadablePartialManifest partialManifest = new StandardReadablePartialManifest();
        analyzer.analyse(new FileInputStream("src/test/resources/com/springsource/bundlor/support/contributors/log4j-1.xml"), null, partialManifest);

        Set<String> importedPackages = partialManifest.getImportedPackages();
        assertEquals(1, importedPackages.size());
        assertTrue(importedPackages.contains("org.apache.log4j"));
    }

    @Test
    public void example2() throws FileNotFoundException, Exception {
        ReadablePartialManifest partialManifest = new StandardReadablePartialManifest();
        analyzer.analyse(new FileInputStream("src/test/resources/com/springsource/bundlor/support/contributors/log4j-2.xml"), null, partialManifest);

        Set<String> importedPackages = partialManifest.getImportedPackages();
        assertEquals(1, importedPackages.size());
        assertTrue(importedPackages.contains("org.apache.log4j"));
    }

    @Test
    public void example3() throws FileNotFoundException, Exception {
        ReadablePartialManifest partialManifest = new StandardReadablePartialManifest();
        analyzer.analyse(new FileInputStream("src/test/resources/com/springsource/bundlor/support/contributors/log4j-3.xml"), null, partialManifest);

        Set<String> importedPackages = partialManifest.getImportedPackages();
        assertEquals(1, importedPackages.size());
        assertTrue(importedPackages.contains("org.apache.log4j"));
    }

    @Test
    public void example4() throws FileNotFoundException, Exception {
        ReadablePartialManifest partialManifest = new StandardReadablePartialManifest();
        analyzer.analyse(new FileInputStream("src/test/resources/com/springsource/bundlor/support/contributors/log4j-4.xml"), null, partialManifest);

        Set<String> importedPackages = partialManifest.getImportedPackages();
        assertEquals(2, importedPackages.size());
        assertTrue(importedPackages.contains("org.apache.log4j"));
        assertTrue(importedPackages.contains("org.apache.log4j.rolling"));
    }
}
